.. paquo documentation

Welcome to PAQUO
================

`paquo` (**PA**\ thological **QU**\ path **O**\ bsession) is a
`Python <https://www.python.org/>`_ library for interacting with
`QuPath <https://qupath.github.io/>`_.

`paquo`'s goal is to provide a pythonic interface to important features of
QuPath, and to make creating and working with QuPath projects intuitive for
Python programmers.

We strive to make your lives as easy as possible: If `paquo` is not pythonic,
unintuitive, slow or if its documentation is confusing, it's a bug in
`paquo`. Feel free to report any issues or feature requests in the issue
tracker on
`github <https://github.com/bayer-science-for-a-better-life/paquo>`_.

This page hosts the documentation for version "|version|".

.. warning::
    Paquo is undergoing heavy development right now and things might change
    frequently. Watch the github repository to stay up to date.

.. sidebar:: Acknowledgements

    Build with love by Santi Villalba and Andreas Poehlmann from the
    *Machine Learning Research* group at Bayer. In collaboration with the
    *Pathology Lab 2* and the *Mechanistic and Toxicologic Pathology* group.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   configuration
   quickstart
   api
